#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ILOG2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ILOG2_HPP_INCLUDED

#include <nt2/bitwise/include/functions/scalar/ilog2.hpp>

#endif
